@@ -1,4 +1,5 @@
 from flag_engine.django_transform.schemas import (
+    DjangoEnvironmentAPIKeySchema,
     DjangoEnvironmentSchema,
     DjangoIdentitySchema,
 )
@@ -6,6 +7,8 @@ from flag_engine.django_transform.schemas import (
 django_environment_schema = DjangoEnvironmentSchema()
 django_identity_schema = DjangoIdentitySchema()
 
+django_environment_api_key_schema = DjangoEnvironmentAPIKeySchema()
+
 
 def build_environment_document(django_environment) -> dict:
     return django_environment_schema.dump(django_environment)
@@ -13,3 +16,7 @@ def build_environment_document(django_environment) -> dict:
 
 def build_identity_document(django_identity) -> dict:
     return django_identity_schema.dump(django_identity)
+
+
+def build_environment_api_key_document(django_environment_api_key) -> dict:
+    return django_environment_api_key_schema.dump(django_environment_api_key)
